# Luxsci.EmailAliasesApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**createAlias**](EmailAliasesApi.md#createAlias) | **POST** /account/{accountId}/aliases | 
[**deleteAlias**](EmailAliasesApi.md#deleteAlias) | **DELETE** /account/{accountId}/aliases/{aliasAddress} | 
[**getAliasDetails**](EmailAliasesApi.md#getAliasDetails) | **GET** /account/{accountId}/aliases/{aliasAddress} | 
[**getAliasesReport**](EmailAliasesApi.md#getAliasesReport) | **GET** /account/{accountId}/aliases | 
[**updateAlias**](EmailAliasesApi.md#updateAlias) | **PUT** /account/{accountId}/aliases/{aliasAddress} | 

<a name="createAlias"></a>
# **createAlias**
> InlineResponse20064 createAlias(accountId, opts)



Create new alias(es) in your account.  Your API Interface looks to see how many aliases were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional alias creation requests until that situation changes. See your API Interface configuration page for your alias creation limit.  Note also that accounts are limited in the maximum number of email aliases permitted per domain. By default, this is 100 + 10 aliases per user in the domain. So, for a domain with 20 users, this would be 100 + 10x20 &#x3D; 300 aliases. {{ACL: Account: Email Aliases - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailAliasesApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'body': new Luxsci.AccountIdAliasesBody(), // AccountIdAliasesBody | The Request body contains the following settings for new email aliases. While you can add multiple aliases at once, you should not have duplicates in your list.
};
apiInstance.createAlias(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **body** | [**AccountIdAliasesBody**](AccountIdAliasesBody.md)| The Request body contains the following settings for new email aliases. While you can add multiple aliases at once, you should not have duplicates in your list. | [optional] 

### Return type

[**InlineResponse20064**](InlineResponse20064.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteAlias"></a>
# **deleteAlias**
> InlineResponse201 deleteAlias(accountId, aliasAddress, opts)



Remove an alias with the specified alias email address from your account. {{ACL: Account: Email Aliases - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailAliasesApi

let accountId = "accountId_example"; // String | 
let aliasAddress = "aliasAddress_example"; // String | 
let opts = { 
};
apiInstance.deleteAlias(accountId, aliasAddress, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **aliasAddress** | **String**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAliasDetails"></a>
# **getAliasDetails**
> InlineResponse20065 getAliasDetails(accountId, aliasAddress, opts)



Get information about a specific email alias. {{ACL: Account: Email Aliases - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailAliasesApi

let accountId = "accountId_example"; // String | 
let aliasAddress = "aliasAddress_example"; // String | 
let opts = { 
};
apiInstance.getAliasDetails(accountId, aliasAddress, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **aliasAddress** | **String**|  | 

### Return type

[**InlineResponse20065**](InlineResponse20065.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAliasesReport"></a>
# **getAliasesReport**
> InlineResponse20063 getAliasesReport(accountId, opts)



Get information about your email aliases including regular aliases user forwards, domain catchalls, and WebAide Group distribution lists. {{ACL: Account: Email Aliases - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailAliasesApi

let accountId = "accountId_example"; // String | 
let opts = { 
};
apiInstance.getAliasesReport(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 

### Return type

[**InlineResponse20063**](InlineResponse20063.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateAlias"></a>
# **updateAlias**
> InlineResponse201 updateAlias(accountId, aliasAddress, opts)



Modify an existing alias in your account.  This function allows you to modify regular email aliases in your account. It does not permit modification of “catch all” aliases, “user forwards,” and system aliases such as WebAide Group Distribution Lists. You can use this function to enable and disable aliases; however, you must use a separate API call to actually delete them. {{ACL: Account: Email Aliases - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailAliasesApi

let accountId = "accountId_example"; // String | 
let aliasAddress = "aliasAddress_example"; // String | 
let opts = { 
  'body': new Luxsci.AliasesAliasAddressBody(), // AliasesAliasAddressBody | The Request body contains the following settings for updating an email alias.
};
apiInstance.updateAlias(accountId, aliasAddress, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **aliasAddress** | **String**|  | 
 **body** | [**AliasesAliasAddressBody**](AliasesAliasAddressBody.md)| The Request body contains the following settings for updating an email alias. | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

