# Luxsci.EmailSendingApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**createAccountSuppression**](EmailSendingApi.md#createAccountSuppression) | **PUT** /account/{accountId}/suppression/ | 
[**createCustomField**](EmailSendingApi.md#createCustomField) | **PUT** /user/{username}/fields | 
[**createEmailContentTag**](EmailSendingApi.md#createEmailContentTag) | **PUT** /user/{username}/content_tags | 
[**createEmailTemplate**](EmailSendingApi.md#createEmailTemplate) | **PUT** /user/{username}/templates | 
[**createEmailTemplateGroup**](EmailSendingApi.md#createEmailTemplateGroup) | **PUT** /user/{username}/template_group/{template_group_id} | 
[**createUserSuppression**](EmailSendingApi.md#createUserSuppression) | **PUT** /user/{username}/suppression/ | 
[**deleteAccountSuppression**](EmailSendingApi.md#deleteAccountSuppression) | **DELETE** /account/{accountId}/suppression/{email} | 
[**deleteEmailContentTag**](EmailSendingApi.md#deleteEmailContentTag) | **DELETE** /user/{username}/content_tags/{tag_id} | 
[**deleteEmailTemplate**](EmailSendingApi.md#deleteEmailTemplate) | **DELETE** /user/{username}/template/{template_id} | 
[**deleteEmailTemplateGroup**](EmailSendingApi.md#deleteEmailTemplateGroup) | **DELETE** /user/{username}/template_group/{template_group_id} | 
[**deleteUserSuppression**](EmailSendingApi.md#deleteUserSuppression) | **DELETE** /user/{username}/suppression/{email} | 
[**getAccountSuppression**](EmailSendingApi.md#getAccountSuppression) | **GET** /account/{accountId}/suppression/{email} | 
[**getAccountSuppressionList**](EmailSendingApi.md#getAccountSuppressionList) | **GET** /account/{accountId}/suppression/ | 
[**getCustomFields**](EmailSendingApi.md#getCustomFields) | **GET** /user/{username}/fields | 
[**getDomainSmtpTlsCapability**](EmailSendingApi.md#getDomainSmtpTlsCapability) | **GET** /user/{username}/email/compose/secureline/tls/{domain} | 
[**getEmailContentTag**](EmailSendingApi.md#getEmailContentTag) | **GET** /user/{username}/content_tags/{tag_id} | 
[**getEmailContentTagList**](EmailSendingApi.md#getEmailContentTagList) | **GET** /user/{username}/content_tags | 
[**getEmailTemplate**](EmailSendingApi.md#getEmailTemplate) | **GET** /user/{username}/template/{template_id} | 
[**getEmailTemplateGroups**](EmailSendingApi.md#getEmailTemplateGroups) | **GET** /user/{username}/template_groups | 
[**getEmailTemplateList**](EmailSendingApi.md#getEmailTemplateList) | **GET** /user/{username}/templates | 
[**getUserSuppression**](EmailSendingApi.md#getUserSuppression) | **GET** /user/{username}/suppression/{email} | 
[**getUserSuppressionList**](EmailSendingApi.md#getUserSuppressionList) | **GET** /user/{username}/suppression/ | 
[**sendEmail**](EmailSendingApi.md#sendEmail) | **POST** /user/{username}/email/send | 
[**sendSecureEmailOrSecureText**](EmailSendingApi.md#sendSecureEmailOrSecureText) | **POST** /user/{username}/email/compose/secureline/send | 
[**updateEmailContentTag**](EmailSendingApi.md#updateEmailContentTag) | **POST** /user/{username}/content_tags/{tag_id} | 
[**updateEmailTemplate**](EmailSendingApi.md#updateEmailTemplate) | **POST** /user/{username}/template/{template_id} | 
[**updateEmailTemplateGroup**](EmailSendingApi.md#updateEmailTemplateGroup) | **POST** /user/{username}/template_group/{template_group_id} | 

<a name="createAccountSuppression"></a>
# **createAccountSuppression**
> InlineResponse2003 createAccountSuppression(accountId, opts)



Add new email suppressions at the account level. {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let accountId = 56; // Number | 
let opts = { 
  'body': new Luxsci.Suppression(), // Suppression | 
};
apiInstance.createAccountSuppression(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **Number**|  | 
 **body** | [**Suppression**](Suppression.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="createCustomField"></a>
# **createCustomField**
> InlineResponse201 createCustomField(username, opts)



Create a Custom Field.  These Custom Fields are useful for Secure Marketing v3 and for Advanced Secure High Volume.  Note that for users in Teams, only Team Administrators are permitted to make new Custom Fields. {{ACL: User Email: Custom Fields}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'body': new Luxsci.UsernameFieldsBody(), // UsernameFieldsBody | 
};
apiInstance.createCustomField(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**UsernameFieldsBody**](UsernameFieldsBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="createEmailContentTag"></a>
# **createEmailContentTag**
> InlineResponse20017 createEmailContentTag(username, opts)



Define a new static email content tag.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'body': new Luxsci.ContentTag(), // ContentTag | 
};
apiInstance.createEmailContentTag(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**ContentTag**](ContentTag.md)|  | [optional] 

### Return type

[**InlineResponse20017**](InlineResponse20017.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="createEmailTemplate"></a>
# **createEmailTemplate**
> InlineResponse20015 createEmailTemplate(username, opts)



Create a new email template.  Note, templates created via the API will be required to use the WYSIWYG template editor if edited in the user interface.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'body': new Luxsci.Template(), // Template | 
};
apiInstance.createEmailTemplate(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**Template**](Template.md)|  | [optional] 

### Return type

[**InlineResponse20015**](InlineResponse20015.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="createEmailTemplateGroup"></a>
# **createEmailTemplateGroup**
> InlineResponse20019 createEmailTemplateGroup(username, opts)



Create a new email template group. {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'body': new Luxsci.TemplateGroupTemplateGroupIdBody(), // TemplateGroupTemplateGroupIdBody | 
};
apiInstance.createEmailTemplateGroup(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**TemplateGroupTemplateGroupIdBody**](TemplateGroupTemplateGroupIdBody.md)|  | [optional] 

### Return type

[**InlineResponse20019**](InlineResponse20019.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="createUserSuppression"></a>
# **createUserSuppression**
> InlineResponse2003 createUserSuppression(username, opts)



Add new email suppressions at the user level. {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'body': new Luxsci.Suppression(), // Suppression | 
};
apiInstance.createUserSuppression(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**Suppression**](Suppression.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteAccountSuppression"></a>
# **deleteAccountSuppression**
> InlineResponse2003 deleteAccountSuppression(accountId, email, opts)



Delete a specific account-level email suppression. {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let accountId = "accountId_example"; // String | 
let email = "email_example"; // String | Suppression email address to be deleted.
let opts = { 
};
apiInstance.deleteAccountSuppression(accountId, email, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **email** | **String**| Suppression email address to be deleted. | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteEmailContentTag"></a>
# **deleteEmailContentTag**
> InlineResponse2003 deleteEmailContentTag(username, tagId, opts)



Delete a specific email content tag.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let tagId = "tagId_example"; // String | tag_id can be either the unique numerical tag_id or the text code_word
let opts = { 
};
apiInstance.deleteEmailContentTag(username, tagId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **tagId** | **String**| tag_id can be either the unique numerical tag_id or the text code_word | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteEmailTemplate"></a>
# **deleteEmailTemplate**
> InlineResponse2003 deleteEmailTemplate(username, templateId, opts)



Delete a specific email template.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let templateId = "templateId_example"; // String | template_id can be either the unique numerical template_id or the text code_word
let opts = { 
};
apiInstance.deleteEmailTemplate(username, templateId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **templateId** | **String**| template_id can be either the unique numerical template_id or the text code_word | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteEmailTemplateGroup"></a>
# **deleteEmailTemplateGroup**
> InlineResponse2003 deleteEmailTemplateGroup(username, templateGroupId, opts)



Delete a specific email template group.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let templateGroupId = "templateGroupId_example"; // String | Unique Id for this template group.
let opts = { 
};
apiInstance.deleteEmailTemplateGroup(username, templateGroupId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **templateGroupId** | **String**| Unique Id for this template group. | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteUserSuppression"></a>
# **deleteUserSuppression**
> InlineResponse2003 deleteUserSuppression(username, email, opts)



Delete a specific user-level email suppression. {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let email = "email_example"; // String | Suppression email address to be deleted.
let opts = { 
};
apiInstance.deleteUserSuppression(username, email, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **email** | **String**| Suppression email address to be deleted. | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAccountSuppression"></a>
# **getAccountSuppression**
> InlineResponse20012 getAccountSuppression(accountId, email, opts)



Retrieve a specific email suppression at the account level. {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let accountId = 56; // Number | 
let email = "email_example"; // String | Suppression email address to be retrieved. You are returning all suppression entries that contain the string 'email'.  Note that even if you specify a full email address for 'email,' you can get multiple matches.
let opts = { 
};
apiInstance.getAccountSuppression(accountId, email, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **Number**|  | 
 **email** | **String**| Suppression email address to be retrieved. You are returning all suppression entries that contain the string &#x27;email&#x27;.  Note that even if you specify a full email address for &#x27;email,&#x27; you can get multiple matches. | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAccountSuppressionList"></a>
# **getAccountSuppressionList**
> InlineResponse20012 getAccountSuppressionList(accountId, opts)



Retrieve all email suppressions at the account level. See also the newer and more general function: getAccountSuppressionReport.  {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let accountId = "accountId_example"; // String | 
let opts = { 
};
apiInstance.getAccountSuppressionList(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getCustomFields"></a>
# **getCustomFields**
> InlineResponse20044 getCustomFields(username, opts)



Retrieve a list of all Custom Fields visible to user {username}.  These Custom Fields are useful for Secure Marketing v3 and for Advanced Secure High Volume. {{ACL: User Email: Custom Fields}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
};
apiInstance.getCustomFields(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20044**](InlineResponse20044.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDomainSmtpTlsCapability"></a>
# **getDomainSmtpTlsCapability**
> InlineResponse20010 getDomainSmtpTlsCapability(username, domain, opts)



This function checks if a specific domain name supports “good” SMTP TLS for email delivery to its users. This means: - All MX records are working - SMTP TLS is supported by all MX records - TLS support includes TLS v1.0+ and strong (NIST 800-52 recommended) ciphers like AES256.  For more background, see: - [About SMTP TLS](https://luxsci.com/blog/smtp-tls-all-about-secure-email-delivery-over-tls.html) - [What Level of SSL/TLS is needed for HIPAA?](https://luxsci.com/blog/level-ssl-tls-required-hipaa.html) {{ACL: User Email - Sending}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let domain = "domain_example"; // String | 
let opts = { 
};
apiInstance.getDomainSmtpTlsCapability(username, domain, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **domain** | **String**|  | 

### Return type

[**InlineResponse20010**](InlineResponse20010.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailContentTag"></a>
# **getEmailContentTag**
> InlineResponse20018 getEmailContentTag(username, tagId, opts)



The call returns the specific details around a specific Email Content Tag {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let tagId = "tagId_example"; // String | can either be the numerical unique ID of the Cotent Tag, or its 'code_word'
let opts = { 
};
apiInstance.getEmailContentTag(username, tagId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **tagId** | **String**| can either be the numerical unique ID of the Cotent Tag, or its &#x27;code_word&#x27; | 

### Return type

[**InlineResponse20018**](InlineResponse20018.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailContentTagList"></a>
# **getEmailContentTagList**
> InlineResponse20016 getEmailContentTagList(username, opts)



This function returns a list of all content tags accessible to you.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
};
apiInstance.getEmailContentTagList(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20016**](InlineResponse20016.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailTemplate"></a>
# **getEmailTemplate**
> InlineResponse20013 getEmailTemplate(username, templateId, opts)



The call returns the specific details around a specific Email Template. {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let templateId = "templateId_example"; // String | can either be the numerical unique ID of the template, or the textual “code_word”
let opts = { 
};
apiInstance.getEmailTemplate(username, templateId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **templateId** | **String**| can either be the numerical unique ID of the template, or the textual “code_word” | 

### Return type

[**InlineResponse20013**](InlineResponse20013.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailTemplateGroups"></a>
# **getEmailTemplateGroups**
> InlineResponse20020 getEmailTemplateGroups(username, opts)



This function returns a list of all templates groups accessible to you.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
};
apiInstance.getEmailTemplateGroups(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20020**](InlineResponse20020.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailTemplateList"></a>
# **getEmailTemplateList**
> InlineResponse20014 getEmailTemplateList(username, opts)



This function returns a list of all templates accessible to you.  {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'userId': 56, // Number | Restricts the templates returned to only those owned by a specific user, [user_id].  This is relevent when [username] used belongs to a Team. In that case, all non-private Templates of all Team members are returned by this call unless this parameter is specified.
};
apiInstance.getEmailTemplateList(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **userId** | **Number**| Restricts the templates returned to only those owned by a specific user, [user_id].  This is relevent when [username] used belongs to a Team. In that case, all non-private Templates of all Team members are returned by this call unless this parameter is specified. | [optional] 

### Return type

[**InlineResponse20014**](InlineResponse20014.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getUserSuppression"></a>
# **getUserSuppression**
> InlineResponse20012 getUserSuppression(username, email, opts)



Retrieve a specific email suppression at the user level. {{ACL: User Email: Suppression}}.  See also the newer and more general function: getUserSuppressionReport.

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let email = "email_example"; // String | Suppression email address to be retrieved. You are returning all suppression entries that contain the string 'email'.  Note that even if you specify a full email address for 'email,' you can get multiple matches.
let opts = { 
};
apiInstance.getUserSuppression(username, email, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **email** | **String**| Suppression email address to be retrieved. You are returning all suppression entries that contain the string &#x27;email&#x27;.  Note that even if you specify a full email address for &#x27;email,&#x27; you can get multiple matches. | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getUserSuppressionList"></a>
# **getUserSuppressionList**
> InlineResponse20012 getUserSuppressionList(username, opts)



Retrieve all email suppressions at the user level in a simple list. {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
};
apiInstance.getUserSuppressionList(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="sendEmail"></a>
# **sendEmail**
> InlineResponse20012 sendEmail(username, opts)



This API call is a generic outbound email sending interface that is designed to enable efficient large-scale email sending through your account’s email servers.  It is ideal for Secure High Volume email sending.  See - [sendEmail vs sendSecureEmailOrSecureText endpoints](/rest-api/sending-email.html) for sending email via the LuxSci API.  This API function is used to send message(s) through your account’s SMTP server(s). You can think of it as an API-based proxy to SMTP, used for cases where direct use of SMTP is not an option. Generally speaking, direct use of SMTP is overall faster and more efficient; however, the API does include some things that you cannot get through direct SMTP connections. For example, the API includes support for failover, load-balanced SMTP servers; this can be done with direct SMTP only if you have a load balancer in front of your servers. You can also hand off messages to LuxSci (into the outbound queues) faster through the API than you can through direct SMTP.  As this is a proxy for SMTP, the majority of the email message processing actually happens on the SMTP servers themselves (just like it would if you had actually used direct SMTP to send the message). The API call accepts the message, vets your ability to send the message, queues the message, and the moves it to the appropriate SMTP servers for delivery. This API process is designed to be very safe and efficient and works well for customers with very large SMTP sending limits (e.g., millions of messages per month).  This API function allows you to optionally include attachments. If you wish to include attachments, you must format your request as a &#x60;multipart/form-data&#x60; request as discussed in the [API Mechanics Guide](/rest-api/mechanics.html).  If the API call &#x27;fails&#x27; it may be because more information is needed to encrypt the message to your recipients, if the request is malformed, or if your sending has exceeded some limit. Here are some limits to be aware of  1. The sending user must have an SMTP license. 2. The sending user must have a SecureLine license to use SecureLine-specific parameters. 3. You have to send to at least 1 recipient, but no more than 100 recipients per message. This limit can be increased on dedicated servers. 4. Your API call can contain 1 to 1000 messages. This limit can be increased on dedicated servers. 5. The total number of recipients across all messages in your API call cannot exceed 1000. This limit can be increased on dedicated servers. 6. The messages sent by a user through this API call count towards the users’ daily and monthly SMTP sending (just as if the user had actually used direct SMTP to send) totals. So, messages will be rejected if a user exceeds any of these limits. Please contact support if you need to upgrade these limits. 7. While SecureLine-encrypted emails sending is supported through this API call, SecureText sending is not. 8. If there are restrictions configured in the Domain Administration control panel on to whom the sending user can send messages, these restrictions also apply to messages sent through the API. 9. The total size of the message subject, body, and all attachments (raw size) must be less than or equal to 66% the sender’s SMTP message sending size limit. This limit can be affected by use of Email Archival, custom domain-level size limits, and general global limits. The current value of this limit can be found in the “Maximum Message Size Limit” for the sender’s domain in your domain administration settings area. 66% is used because, when the attachments are encoded into an actual email message, the size can bloat to 140-150% of the raw size; the SMTP message size limit looks at the size of the encoded messages passing through your SMTP servers.  Note that once messages sent via this API arrive on your SMTP server for processing and delivery, those messages are subject to any server delivery rate limiting settings currently enabled on the SMTP server. For example, if your SMTP server is “warming up” its IP address by slowly increasing its outbound email delivery rate, messages sent by the API through that server may be delayed by that warmup rate limit.  **Maximizing your sending rate:**  To deposit email messages in the outbound queues as fast as possible using the API, we recommend  1. Send as many messages as you can in each API call. This “pipelining” greatly reduces the number of API calls you need to execute and greatly speeds up processing of your messages. 2. When sending same attachments in multiple messages, use the API’s feature for including the attachment once and referencing it in each of the actual messages. This will greatly speed up the uploading/posting of your message information to the API server. 3. Keep the messages as small as possible. 4. If appropriate for your use case, send fewer messages. Have more recipients per message (using the &#x60;bcc&#x60; field if needed). 5. Ask support about dedicated API servers. If all of the server resources are dedicated to your account, your throughput can be higher. You can also use multiple load-balanced dedicated API sending servers to scale your throughput capacity. 6. Use the &#x60;priority&#x60; field to ensure that more important messages are processed and delivered before less important messages.  Under ideal conditions, you should be able to deposit outbound email messages in the API queues much faster that your email servers can actually deliver those messages to the actual recipients (unless you have a number of powerful dedicated email servers). That is OK, your email servers will just process and delivery them as fast as they can. The actual rate of message delivery to the recipients will be a function of how many email servers you have, what their specs are, how busy they are, and many other factors involved in SMTP email delivery – such as the recipients’ DNS response time, the recipient’s inbound email server speeds, etc. {{ACL: User Email: Sending}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'body': new Luxsci.EmailSendBody(), // EmailSendBody | 
};
apiInstance.sendEmail(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**EmailSendBody**](EmailSendBody.md)|  | [optional] 
 **json** | [**UserusernameemailsendJson**](.md)|  | [optional] 
 **files** | [**[Blob]**](Blob.md)|  | [optional] 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

<a name="sendSecureEmailOrSecureText"></a>
# **sendSecureEmailOrSecureText**
> InlineResponse201 sendSecureEmailOrSecureText(username, opts)



Send Secure Email and/or SecureText messages through your WebMail servers.  This API endpoint is deprecated; use the sendEmail endpoint instead. See [sendEmail vs sendSecureEmailOrSecureText endpoints](/rest-api/sending-email.html) for sending email via the LuxSci API. {{ACL: User Email: Sending}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let opts = { 
  'body': new Luxsci.SecurelineSendBody(), // SecurelineSendBody | 
};
apiInstance.sendSecureEmailOrSecureText(username, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**SecurelineSendBody**](SecurelineSendBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateEmailContentTag"></a>
# **updateEmailContentTag**
> InlineResponse2003 updateEmailContentTag(username, tagId, opts)



This content tag update call will update/replace ALL FIELDS. So, include all fields, as omitted fields will be treated as if you are updating them with empty or false values.  This is effectively just like deleting the old tag with this &#x60;tag_id&#x60; and replacing it with the new data. Note, this call does not allow you to change the type of a Contet Tag or alter the inclusion rules for Dynamic Content Tags. {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let tagId = "tagId_example"; // String | tag_id can be either the unique numerical tag_id or the code_word.
let opts = { 
  'body': new Luxsci.ContentTag(), // ContentTag | 
};
apiInstance.updateEmailContentTag(username, tagId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **tagId** | **String**| tag_id can be either the unique numerical tag_id or the code_word. | 
 **body** | [**ContentTag**](ContentTag.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateEmailTemplate"></a>
# **updateEmailTemplate**
> InlineResponse2003 updateEmailTemplate(username, templateId, opts)



This template update call will update/replace ALL FIELDS. So, include all fields, as omitted fields will be treated as if you are updating them with empty or false values.  This is effectively just like deleting the old template with this &#x60;template_id&#x60; and replacing it with the new data.  Note, any template updated from the API will be required to use the WYSIWYG template editor when edited in the user interface. {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let templateId = "templateId_example"; // String | template_id can be either the unique numerical template_id or the text code_word.
let opts = { 
  'body': new Luxsci.Template(), // Template | 
};
apiInstance.updateEmailTemplate(username, templateId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **templateId** | **String**| template_id can be either the unique numerical template_id or the text code_word. | 
 **body** | [**Template**](Template.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateEmailTemplateGroup"></a>
# **updateEmailTemplateGroup**
> InlineResponse2003 updateEmailTemplateGroup(username, templateGroupId, opts)



Update the Template Group name. {{ACL: User Email: Templates}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.EmailSendingApi

let username = "username_example"; // String | 
let templateGroupId = "templateGroupId_example"; // String | Unique Id for this template group.
let opts = { 
  'body': new Luxsci.TemplateGroupTemplateGroupIdBody1(), // TemplateGroupTemplateGroupIdBody1 | 
};
apiInstance.updateEmailTemplateGroup(username, templateGroupId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **templateGroupId** | **String**| Unique Id for this template group. | 
 **body** | [**TemplateGroupTemplateGroupIdBody1**](TemplateGroupTemplateGroupIdBody1.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

